@@ -1,5 +1,6 @@
 from copy import deepcopy
 
+from hdx.location.country import Country
 from hdx.utilities.dateparse import parse_date
 
 from hdx.scraper.base_scraper import BaseScraper
@@ -25,7 +26,7 @@ class TestScrapersAppendData:
             "SOM",
         )
         runner = Runner(iso3s, today)
-        names = ["key_figures_som", "key_figures_eth", "key_figures_ken"]
+        names = ["key_figures_eth", "key_figures_ken", "key_figures_som"]
         keys = runner.add_configurables(
             scraper_configuration,
             level,
@@ -86,257 +87,257 @@ class TestScrapersAppendData:
             {"ETH": "8200000", "KEN": "4100000", "SOM": "3900000"},
         ]
         sources = [
-            (
-                "#value+funding+required+usd+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#value+funding+total+usd+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#value+funding+pct+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#inneed+total+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#targeted+total+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#targeted+pct+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#reached+total+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#reached+pct+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#affected+food+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#affected+sam+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#affected+mam+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#affected+gam+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#affected+idps+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
-            (
-                "#affected+water+som",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
-            ),
             (
                 "#value+funding+required+usd+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#value+funding+total+usd+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#value+funding+pct+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#inneed+total+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#targeted+total+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#targeted+pct+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#reached+total+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#reached+pct+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#affected+food+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#affected+sam+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#affected+mam+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#affected+gam+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#affected+idps+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#affected+water+eth",
-                "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
             ),
             (
                 "#value+funding+required+usd+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#value+funding+total+usd+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#value+funding+pct+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#inneed+total+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#targeted+total+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#targeted+pct+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#reached+total+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#reached+pct+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#affected+food+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#affected+sam+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#affected+mam+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#affected+gam+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#affected+idps+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             ),
             (
                 "#affected+water+ken",
                 "Oct 01, 2020",
-                "multiple",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
+            ),
+            (
+                "#value+funding+required+usd+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#value+funding+total+usd+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#value+funding+pct+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#inneed+total+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#targeted+total+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#targeted+pct+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#reached+total+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#reached+pct+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#affected+food+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#affected+sam+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#affected+mam+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#affected+gam+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#affected+idps+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ),
+            (
+                "#affected+water+som",
+                "Oct 01, 2020",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
             ),
         ]
         run_check_scrapers(
@@ -347,9 +348,85 @@ class TestScrapersAppendData:
             values,
             sources,
             source_urls=[
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+            ],
+            set_not_run=False,
+        )
+
+        names = runner.add_aggregators(
+            True,
+            configuration["aggregate_append_data"],
+            "national",
+            "regional",
+            iso3s,
+            force_add_to_run=True,
+        )
+        assert names == [
+            "affected_sam_regional",
+            "affected_mam_regional",
+            "affected_gam_regional",
+            "affected_water_regional",
+        ]
+        headers = (
+            [
+                "SAM",
+                "MAM",
+                "GAM",
+                "Water Insecurity",
+            ],
+            [
+                "#affected+sam",
+                "#affected+mam",
+                "#affected+gam",
+                "#affected+water",
+            ],
+        )
+        values = [
+            {"value": 1313619},
+            {"value": 3257327},
+            {"value": 4570946},
+            {"value": 16200000},
+        ]
+        sources = [
+            (
+                "#affected+sam",
+                "Oct 2021-Nov 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset?groups=eth&groups=ken&groups=som&organization=ocha-rosea&vocab_Topics=droughts&q=&sort=score%20desc%2C%20if(gt(last_modified%2Creview_date)%2Clast_modified%2Creview_date)%20desc&ext_page_size=25",
+            ),
+            (
+                "#affected+mam",
+                "01-10-2021:01-11-2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset?groups=eth&groups=ken&groups=som&organization=ocha-rosea&vocab_Topics=droughts&q=&sort=score%20desc%2C%20if(gt(last_modified%2Creview_date)%2Clast_modified%2Creview_date)%20desc&ext_page_size=25",
+            ),
+            (
+                "#affected+gam",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset?groups=eth&groups=ken&groups=som&organization=ocha-rosea&vocab_Topics=droughts&q=&sort=score%20desc%2C%20if(gt(last_modified%2Creview_date)%2Clast_modified%2Creview_date)%20desc&ext_page_size=25",
+            ),
+            (
+                "#affected+water",
+                "Nov 01, 2022",
+                "Multiple Source (Humanitarian Partners)",
+                "https://data.humdata.org/dataset?groups=eth&groups=ken&groups=som&organization=ocha-rosea&vocab_Topics=droughts&q=&sort=score%20desc%2C%20if(gt(last_modified%2Creview_date)%2Clast_modified%2Creview_date)%20desc&ext_page_size=25",
+            ),
+        ]
+        run_check_scrapers(
+            names,
+            runner,
+            "regional",
+            headers,
+            values,
+            sources,
+            source_urls=[
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
+                "https://data.humdata.org/dataset?groups=eth&groups=ken&groups=som&organization=ocha-rosea&vocab_Topics=droughts&q=&sort=score%20desc%2C%20if(gt(last_modified%2Creview_date)%2Clast_modified%2Creview_date)%20desc&ext_page_size=25",
             ],
         )
 
@@ -415,20 +492,23 @@ class TestScrapersAppendData:
             {"ETH": "8200000", "KEN": "4100000", "SOM": "3900000"},
         ]
 
-        def get_expected_sources(headers, countryiso3):
+        def get_expected_sources(headers, date, countryiso3):
             sources = list()
+            countryname = Country.get_country_name_from_iso3(
+                countryiso3
+            ).lower()
             for hxltag in headers[1]:
                 sources.append(
                     (
                         hxltag,
-                        "Oct 01, 2020",
-                        "multiple",
-                        f"https://data.humdata.org/dataset/{countryiso3.lower()}-key-figures-2022",
+                        date,
+                        "Multiple Source (Humanitarian Partners)",
+                        f"https://data.humdata.org/dataset/{countryname}-drought-related-key-figures",
                     )
                 )
             return sources
 
-        def get_expected_sources_data(headers, countryiso3):
+        def get_expected_sources_data(headers, date, countryiso3):
             sources_data = [
                 {
                     "#date": "Feb 24, 2022",
@@ -437,19 +517,22 @@ class TestScrapersAppendData:
                     "#meta+url": "https://meduza.io/en/news/2022/02/24/putin-announces-start-of-military-operation-in-eastern-ukraine",
                 }
             ]
+            countryname = Country.get_country_name_from_iso3(
+                countryiso3
+            ).lower()
             for hxltag in headers[1]:
                 sources_data.append(
                     {
-                        "#date": "Oct 01, 2020",
+                        "#date": date,
                         "#indicator+name": hxltag,
-                        "#meta+source": "multiple",
-                        "#meta+url": f"https://data.humdata.org/dataset/{countryiso3.lower()}-key-figures-2022",
+                        "#meta+source": "Multiple Source (Humanitarian Partners)",
+                        "#meta+url": f"https://data.humdata.org/dataset/{countryname}-drought-related-key-figures",
                     },
                 )
             return sources_data
 
         runner = Runner(iso3s, today)
-        names = ["key_figures_som", "key_figures_eth", "key_figures_ken"]
+        names = ["key_figures_eth", "key_figures_ken", "key_figures_som"]
         keys = runner.add_configurables(scraper_configuration, level)
         assert keys == names
         run_check_scrapers(
@@ -458,11 +541,11 @@ class TestScrapersAppendData:
             level,
             headers,
             values,
-            get_expected_sources(headers, "SOM"),
+            get_expected_sources(headers, "Nov 01, 2022", "ETH"),
             source_urls=[
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
             ],
             set_not_run=False,
         )
@@ -473,9 +556,9 @@ class TestScrapersAppendData:
         additional_sources.append(
             {
                 "indicator": "#value+funding+required+usd",
-                "source_date": "Oct 01, 2020",
-                "source": "multiple",
-                "source_url": "https://data.humdata.org/dataset/ken-key-figures-2022",
+                "source_date": "Nov 01, 2022",
+                "source": "Multiple Source (Humanitarian Partners)",
+                "source_url": "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
             }
         )
         writer = Writer(runner, outputs)
@@ -484,12 +567,12 @@ class TestScrapersAppendData:
             secondary_runner=runner,  # to check we don't get duplicate sources
         )
         assert jsonout.json["sources_data"] == get_expected_sources_data(
-            headers, "SOM"
+            headers, "Nov 01, 2022", "ETH"
         )
 
         Sources.set_should_overwrite_sources(True)
         runner = Runner(iso3s, today)
-        names = ["key_figures_som", "key_figures_eth", "key_figures_ken"]
+        names = ["key_figures_eth", "key_figures_ken", "key_figures_som"]
         keys = runner.add_configurables(scraper_configuration, level)
         assert keys == names
         run_check_scrapers(
@@ -498,11 +581,11 @@ class TestScrapersAppendData:
             level,
             headers,
             values,
-            get_expected_sources(headers, "KEN"),
+            get_expected_sources(headers, "Oct 01, 2020", "SOM"),
             source_urls=[
-                "https://data.humdata.org/dataset/eth-key-figures-2022",
-                "https://data.humdata.org/dataset/ken-key-figures-2022",
-                "https://data.humdata.org/dataset/som-key-figures-2022",
+                "https://data.humdata.org/dataset/ethiopia-drought-related-key-figures",
+                "https://data.humdata.org/dataset/kenya-drought-related-key-figures",
+                "https://data.humdata.org/dataset/somalia-drought-related-key-figures",
             ],
             set_not_run=False,
         )
@@ -524,5 +607,5 @@ class TestScrapersAppendData:
             secondary_runner=runner,  # to check we don't get duplicate sources
         )
         assert jsonout.json["sources_data"] == get_expected_sources_data(
-            headers, "KEN"
+            headers, "Oct 01, 2020", "SOM"
         )
