@@ -75,85 +75,85 @@ class TestScrapersMultipleURLs:
         sources = [
             (
                 "#value+funding+required+usd",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#value+funding+total+usd",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#value+funding+pct",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#inneed+total",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#targeted+total",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#targeted+pct",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#reached+total",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#reached+pct",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#affected+food",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#affected+sam",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#affected+mam",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#affected+gam",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#affected+idps",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
             (
                 "#affected+water",
-                "2020-10-01",
+                "Oct 01, 2020",
                 "multiple",
                 "https://data.humdata.org/dataset/key-figures-2022",
             ),
